@@ -47,7 +47,7 @@ from pytket.passes import (  # type: ignore
     RebaseCustom,
     RemoveRedundancies,
     SequencePass,
-    SynthesiseIBM,
+    SynthesiseTket,
     FullPeepholeOptimise,
     CliffordSimp,
     SquashCustom,
@@ -107,6 +107,7 @@ _gate_types = {
     "cswap": OpType.CSWAP,
     "cy": OpType.CY,
     "cz": OpType.CZ,
+    "end_verbatim_box": None,
     "h": OpType.H,
     "i": OpType.noop,
     "iswap": OpType.ISWAPMax,
@@ -117,6 +118,7 @@ _gate_types = {
     "rz": OpType.Rz,
     "s": OpType.S,
     "si": OpType.Sdg,
+    "start_verbatim_box": None,
     "swap": OpType.SWAP,
     "t": OpType.T,
     "ti": OpType.Tdg,
@@ -162,7 +164,7 @@ _observables = {
 
 def _obs_from_qps(pauli: QubitPauliString) -> Tuple[Observable, QubitSet]:
     obs, qbs = [], []
-    for q, p in pauli.to_dict().items():
+    for q, p in pauli.map.items():
         obs.append(_observables[p])
         qbs.append(q.index[0])
     return Observable.TensorProduct(obs), qbs
@@ -423,13 +425,9 @@ class BraketBackend(Backend):
                 __extension_version__,
                 arch,
                 self._singleqs.union(self._multiqs),
-                misc={
-                    "characterisation": {
-                        "NodeErrors": node_errors,
-                        "EdgeErrors": link_errors,
-                        "ReadoutErrors": readout_errors,
-                    }
-                },
+                all_node_gate_errors=node_errors,
+                all_edge_gate_errors=link_errors,
+                all_readout_errors=readout_errors,
             )
         else:
             self._backend_info = BackendInfo(
@@ -459,7 +457,7 @@ class BraketBackend(Backend):
         assert optimisation_level in range(3)
         passes = [DecomposeBoxes()]
         if optimisation_level == 1:
-            passes.append(SynthesiseIBM())
+            passes.append(SynthesiseTket())
         elif optimisation_level == 2:
             passes.append(FullPeepholeOptimise())
         passes.append(self._rebase_pass)
@@ -483,7 +481,7 @@ class BraketBackend(Backend):
             passes.extend(
                 [
                     CliffordSimp(False),
-                    SynthesiseIBM(),
+                    SynthesiseTket(),
                     self._rebase_pass,
                     self._squash_pass,
                 ]
@@ -516,7 +514,7 @@ class BraketBackend(Backend):
     def process_circuits(
         self,
         circuits: Sequence[Circuit],
-        n_shots: Optional[Union[int, Sequence[int]]] = None,
+        n_shots: Union[None, int, Sequence[Optional[int]]] = None,
         valid_check: bool = True,
         **kwargs: KwargTypes,
     ) -> List[ResultHandle]:
@@ -524,12 +522,9 @@ class BraketBackend(Backend):
         Supported `kwargs`: none
         """
         circuits = list(circuits)
-        n_shots_list: List[int] = []
-        if hasattr(n_shots, "__iter__"):
-            n_shots_list = [n or 0 for n in cast(Sequence[Optional[int]], n_shots)]
-        else:
-            # convert n_shots to a list
-            n_shots_list = [cast(Optional[int], n_shots) or 0] * len(circuits)
+        n_shots_list = Backend._get_n_shots_as_list(
+            n_shots, len(circuits), optional=True, set_zero=True
+        )
 
         if not self.supports_shots and not self.supports_state:
             raise RuntimeError("Backend does not support shots or state")
@@ -620,8 +615,11 @@ class BraketBackend(Backend):
 
     @property
     def characterisation(self) -> Optional[Dict[str, Any]]:
-        char = self._backend_info.get_misc("characterisation")
-        return cast(Dict[str, Any], char) if char else None
+        return {
+            "NodeErrors": self._backend_info.all_node_gate_errors,
+            "EdgeErrors": self._backend_info.all_edge_gate_errors,
+            "ReadoutErrors": self._backend_info.all_readout_errors,
+        }
 
     @property
     def backend_info(self) -> BackendInfo:
